"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sdk_1 = require("@wormhole-foundation/sdk");
const evm_1 = __importDefault(require("@wormhole-foundation/sdk/evm"));
const solana_1 = __importDefault(require("@wormhole-foundation/sdk/solana"));
// register protocol implementations
require("@wormhole-foundation/sdk-evm-ntt");
require("@wormhole-foundation/sdk-solana-ntt");
const consts_js_1 = require("./consts.js");
const helpers_js_1 = require("./helpers.js");
// Recover an in-flight transfer by setting txids here from output of previous run
const recoverTxids = [
// { chain: "Solana", txid: "hZXRs9TEvMWnSAzcgmrEuHsq1C5rbcompy63vkJ2SrXv4a7u6ZBEaJAkBMXKAfScCooDNhN36Jt4PMcDhN8yGjP", },
];
(async function () {
    const wh = await (0, sdk_1.wormhole)("Testnet", [solana_1.default, evm_1.default]);
    const src = wh.getChain("Solana");
    const dst = wh.getChain("ArbitrumSepolia");
    const srcSigner = await (0, helpers_js_1.getSigner)(src);
    const dstSigner = await (0, helpers_js_1.getSigner)(dst);
    const srcNtt = await src.getProtocol("Ntt", {
        ntt: consts_js_1.TEST_NTT_TOKENS[src.chain],
    });
    const dstNtt = await dst.getProtocol("Ntt", {
        ntt: consts_js_1.TEST_NTT_TOKENS[dst.chain],
    });
    // Initiate the transfer (or set to recoverTxids to complete transfer)
    const txids = recoverTxids.length === 0
        ? await (0, sdk_1.signSendWait)(src, srcNtt.transfer(srcSigner.address.address, 1000n, dstSigner.address, {
            queue: false,
            automatic: false,
            gasDropoff: 0n,
        }), srcSigner.signer)
        : recoverTxids;
    console.log("Source txs", txids);
    const vaa = await wh.getVaa(txids[0].txid, "Ntt:WormholeTransfer");
    console.log(vaa);
    const dstTxids = await (0, sdk_1.signSendWait)(dst, dstNtt.redeem([vaa]), dstSigner.signer);
    console.log("dstTxids", dstTxids);
})();
//# sourceMappingURL=index.js.map